@@ -19,7 +19,9 @@ import re
 import subprocess
 import sys
 from typing import Callable, Dict
+import functools
 
+class VersioneerBadRootError(Exception): ... # --STRIP DURING BUILD
 
 class VersioneerConfig:
     """Container for Versioneer configuration parameters."""
@@ -85,7 +87,7 @@ def get_config_from_root(root):
     cfg.versionfile_source = section.get("versionfile_source")
     cfg.versionfile_build = section.get("versionfile_build")
     cfg.tag_prefix = section.get("tag_prefix")
-    if cfg.tag_prefix in ("''", '""'):
+    if cfg.tag_prefix in ("''", '""', None):
         cfg.tag_prefix = ""
     cfg.parentdir_prefix = section.get("parentdir_prefix")
     cfg.verbose = section.get("verbose")
